@@ -47,6 +47,10 @@ signal.signal(signal.SIGINT, signal.SIG_DFL)
 import codecs
 
 import gettext
+
+# Import the gettext function and alias it as _
+from gettext import gettext as _
+
 gettext.bindtextdomain("nemo-extensions")
 gettext.textdomain("nemo-extensions")
 _ = gettext.gettext
@@ -230,7 +234,7 @@ class NemoTerminal(object):
         """
 
         if settings.get_enum("default-follow-mode") in (0, 2):
-            return 
+            return
 
         self._path = self._uri_to_path(uri)
 
@@ -246,12 +250,14 @@ class NemoTerminal(object):
             # Change directory
             cdcmd_nonewline = settings.get_string("terminal-change-directory-command") \
                 % GLib.shell_quote(self._path)
-            cdcmd = "%s\n" % cdcmd_nonewline
-            self.feed_child(cdcmd.encode().decode("unicode_escape"))
+            cdcmd = " %s \n" % cdcmd_nonewline
+            #self.feed_child(cdcmd.encode().decode("unicode_escape"))
+            self.feed_child(cdcmd)
 
             # Restore user input
             restorelinekeys = settings.get_string("terminal-restore-line")
             self.feed_child(restorelinekeys.encode().decode("unicode_escape"))
+            #self.feed_child(restorelinekeys + "\n")
 
     def get_widget(self):
         """Return the top-level widget of Nemo Terminal."""
@@ -406,11 +412,14 @@ class NemoTerminal(object):
         gobject-introspection/python-gi differences force us to try with and
         without the text length. One of them will work.
         """
-        # print("feed '%s'" % text)
+        # print(type(text), "feed '%s'" % text)
         try:
             self.term.feed_child(text.encode())
         except TypeError:
-            self.term.feed_child(text.encode(), len(text))
+            try:
+                self.term.feed_child(text, len(text))
+            except TypeError:
+                self.term.feed_child(text.encode(), len(text))
 
 class Crowbar(object):
     """Modify the Nemo' widget tree when the crowbar is inserted in it.
@@ -472,10 +481,7 @@ class Crowbar(object):
             vpan.show()
             vbox = Gtk.VBox()
             vbox.show()
-            if settings.get_enum("terminal-position") == 0:
-                vpan.add2(vbox)
-            else:
-                vpan.add1(vbox)
+
             #Add the vpan in Nemo, and reparent some widgets
             if len(crowbar_pp_children) == 2:
                 for crowbar_pp_child in crowbar_pp_children:
@@ -483,15 +489,19 @@ class Crowbar(object):
                 crowbar_pp.pack_start(vpan, True, True, 0)
                 vbox.pack_start(crowbar_pp_children[0], False, False, 0)
                 vbox.pack_start(crowbar_pp_children[1], True, True, 0)
-            #Create the terminal
+
             nterm = NemoTerminal(self._uri, self._window)
 
             if hasattr(self._window, "term_visible"):
                 nterm.set_visible(self._window.term_visible)
+
             if settings.get_enum("terminal-position") == 0:
-                vpan.add1(nterm.get_widget())
+                vpan.pack1(nterm.get_widget(), False, False)
+                vpan.pack2(vbox, True, False)
             else:
-                vpan.add2(nterm.get_widget())
+                vpan.pack2(nterm.get_widget(), False, False)
+                vpan.pack1(vbox, True, False)
+
 
     def _on_crowbar_pp_parent_set(self, widget, old_parent):
         """Called when the vpan parent lost his parent.
@@ -570,7 +580,8 @@ class NemoTerminalProvider(GObject.GObject, Nemo.LocationWidgetProvider, Nemo.Na
         return Gdk.EVENT_PROPAGATE
 
     def get_name_and_desc(self):
-        return [("Nemo Terminal:::Embedded terminal for Nemo:::nemo-terminal-prefs")]
+        description = _("Embedded terminal for Nemo")
+        return [(f"nemo-terminal:::{description}:::nemo-terminal-prefs")]
 
 if __name__ == "__main__":
     #Code for testing Nemo Terminal outside of Nemo
